@@ -50,6 +50,7 @@ def isSlience(Filename =None):
     suffix = os.path.splitext(Filename)[-1]
     if suffix == '.mp4':
         Filename = get_wav_from_mp4(Filename)
+        ins, _ = get_data_array(Filename)
     if suffix == '.pcm':
         pcmf = open(Filename, 'rb')
         ins = pcmf.read()
@@ -90,6 +91,6 @@ def audioFormat(wavFileName=None):
     return refChannel,refsamWidth*8,refsamplerate,refframeCount
 
 if __name__ == '__main__':
-    ref = r'C:\Users\vcloud_avl\Documents\我的POPO\src.pcm'
+    ref = r'C:\Users\vcloud_avl\Documents\我的POPO\1meiy.mp4'
     print(isSlience(ref))
     #print(audioFormat(ref))
\ No newline at end of file
